.. py:currentmodule:: pydoover

Config Schema
=============

.. autoclass:: pydoover.config.Schema
   :members:

Config Elements
===============
.. autoclass:: pydoover.config.ConfigElement
   :members:

.. autoclass:: pydoover.config.Integer
    :members:
    :inherited-members:

.. autoclass:: pydoover.config.Number
    :members:
    :inherited-members:

.. autoclass:: pydoover.config.String
    :members:
    :inherited-members:

.. autoclass:: pydoover.config.Boolean
    :members:
.. autoclass:: pydoover.config.Enum
    :members:
.. autoclass:: pydoover.config.Array
    :members:
.. autoclass:: pydoover.config.Object
    :members:
.. autoclass:: pydoover.config.Variable
    :members:
.. autoclass:: pydoover.config.Application
    :members:
